/* -----------------------------------------------------------------------------
*
*  nplinux.c
*
*  ANTz - realtime 3D data visualization tools for the real-world, based on NPE.
*
*  ANTz is hosted at http://openantz.com and NPE at http://neuralphysics.org
*
*  Written in 2010-2012 by Shane Saxon - contact@saxondigital.net
*
*  Please see main.c for a complete list of additional code contributors.
*
*  To the extent possible under law, the author(s) have dedicated all copyright 
*  and related and neighboring rights to this software to the public domain
*  worldwide. This software is distributed without any warranty.
*
*  Released under the CC0 license, which is GPL compatible.
*
*  You should have received a copy of the CC0 Public Domain Dedication along
*  with this software (license file named COPYING.txt). If not, see
*  http://creativecommons.org/publicdomain/zero/1.0/
*
* --------------------------------------------------------------------------- */

#include "nplinux.h"

#include "../../npdata.h"

#ifdef NP_LINUX_

#include <time.h>                // for gettimeofday()
// #include <unistd.h>			//debug zz

//-----------------------------------------------------------------------------
void nplinuxGetAppPath (char* buffer, int* size)
{
	static bool firstTimeCalled = true;
	static char appPath[kNPmaxPath];

	//if first time then set the app path using the CWD method
	//should replace with actual get app path OS function, zz debug
	if (firstTimeCalled)
	{
		nplinuxGetCWD (appPath, size);
		strcat (appPath, "/");
		firstTimeCalled = false;
	}
	
	//copy the app path to the passed in buffer
	strcpy (buffer, appPath);

	//set the length
	*size = strlen(buffer); 
}

// current working directory is OS specific
//-----------------------------------------------------------------------------
void nplinuxGetCWD (char* buffer, int* size)
{
	getcwd (buffer, size);
}

//-----------------------------------------------------------------------------
void nplinuxSetCWD (char* buffer)
{
	setcwd (buffer);
}

//-----------------------------------------------------------------------------
void nplinuxGetOpenFilePath (char* buffer, int* size)
{
	getcwd (buffer, size);
}

//-----------------------------------------------------------------------------
void nplinuxGetOpenFilePath (char* buffer)
{
	return;
}

//-----------------------------------------------------------------------------
double nplinuxGetTime (void)									//untested, debug zz
{
    timeval tval;
	
	// get time of day in micro seconds
    gettimeofday(&tval, NULL);

	// convert us to seconds
	return (double)(tval.tv_sec + tval.tv_usec * 1000000.0);
}

//-----------------------------------------------------------------------------
void nplinuxUpdateTime (void* dataRef)										//debug zz
{
    timeval tval;
	pData data = (pData) dataRef;
	
	double seconds;
	
	// get time of day in micro seconds
    gettimeofday(&tval, NULL);

	// convert us to seconds
	seconds = (double)(tval.tv_sec + tval.tv_usec * 1000000.0);

	if (data->io.timeStart == 0.0)
		data->io.timeStart = seconds;
	else
		data->io.cycleDelta = seconds - data->io.time;
	
	data->io.time = seconds;

	//need to handle the clock rolling over at midnight,					debug zz
}

//-----------------------------------------------------------------------------
void nplinuxSleep (double seconds)
{
	return;																//debug zz
}

//-----------------------------------------------------------------------------
FILE* nplinuxFileDialog (const char* fileName, int dialogType, void* dataRef)
{
	return;																//debug zz
}

//-----------------------------------------------------------------------------
void nplinuxTimeStampCSV (char* fileName)
{
	return;																//debug zz
}

//-----------------------------------------------------------------------------
int nplinuxSetCursorPos (int x, int y)
{
	return 0;																//debug zz
}

//-----------------------------------------------------------------------------
int nplinuxShowCursor (int hide)
{
	return 0;																//debug zz
}


#endif

