/* -----------------------------------------------------------------------------
*
*  npos.c
*
*  ANTz - realtime 3D data visualization tools for the real-world, based on NPE.
*
*  ANTz is hosted at http://openantz.com and NPE at http://neuralphysics.org
*
*  Written in 2010-2012 by Shane Saxon - contact@saxondigital.net
*
*  Please see main.c for a complete list of additional code contributors.
*
*  To the extent possible under law, the author(s) have dedicated all copyright 
*  and related and neighboring rights to this software to the public domain
*  worldwide. This software is distributed without any warranty.
*
*  Released under the CC0 license, which is GPL compatible.
*
*  You should have received a copy of the CC0 Public Domain Dedication along
*  with this software (license file named COPYING.txt). If not, see
*  http://creativecommons.org/publicdomain/zero/1.0/
*
* --------------------------------------------------------------------------- */

#include "npos.h"



//-----------------------------------------------------------------------------
double nposGetTime (void)
{
#ifdef NP_LINUX_
		return nplinuxGetTime ();
#endif
#ifdef NP_MSW_
		return npmswGetTime ();
#endif
#ifdef NP_OSX_
		return nplinuxGetTime ();
		//return nposxGetTime ();	//OSX can often use the linux method
#endif
}

//-----------------------------------------------------------------------------
void nposUpdateTime (void* dataRef)
{
#ifdef NP_LINUX_
		nplinuxUpdateTime (dataRef);
#endif
#ifdef NP_MSW_
		npmswUpdateTime (dataRef);
#endif
#ifdef NP_OSX_
		nplinuxUpdateTime (dataRef);
		//nposxUpdateTime (dataRef);	//OSX can often use the linux method
#endif
}

//-----------------------------------------------------------------------------
void nposSleep (double seconds)
{
#ifdef NP_LINUX_
		nplinuxSleep (seconds);
#endif
#ifdef NP_MSW_
		npmswSleep (seconds);
#endif
#ifdef NP_OSX_
		nplinuxSleep (seconds);
		//nposxSleep (seconds);
#endif
}

//-----------------------------------------------------------------------------
void nposGetAppPath (char* buffer, int* size)
{
#ifdef NP_LINUX_
		nplinuxGetAppPath (buffer, size);
#endif
#ifdef NP_MSW_
		npmswGetAppPath (buffer, size);
#endif
#ifdef NP_OSX_
		nplinuxGetAppPath (buffer, size);
//		nposxGetAppPath (buffer, size);
#endif
}

//-----------------------------------------------------------------------------
void nposGetCWD (char* buffer, int* size)
{
#ifdef NP_LINUX_
		nplinuxGetCWD (buffer, size);
#endif
#ifdef NP_MSW_
		npmswGetCWD (buffer, size);
#endif
#ifdef NP_OSX_
		nplinuxGetCWD (buffer, size);
//		nposxGetCWD (buffer, size);
#endif
}

//-----------------------------------------------------------------------------
void nposSetCWD (char* buffer)
{
#ifdef NP_LINUX_
		nplinuxSetCWD (buffer);
#endif
#ifdef NP_MSW_
		npmswSetCWD (buffer);
#endif
#ifdef NP_OSX_
		nplinuxSetCWD (buffer);
//		nposxSetCWD (buffer);
#endif
}

//-----------------------------------------------------------------------------
void nposGetOpenFilePath (char* buffer, int* size)
{
#ifdef NP_LINUX_
		nplinuxGetOpenFilePath (buffer, size);
#endif
#ifdef NP_MSW_
		npmswGetOpenFilePath (buffer, size);
#endif
#ifdef NP_OSX_
		nplinuxGetOpenFilePath (buffer, size);
//		nposxGetOpenFilePath (buffer, size);
#endif
}

//-----------------------------------------------------------------------------
void nposSetOpenFilePath (char* buffer)
{
#ifdef NP_LINUX_
		nplinuxSetOpenFilePath (buffer);
#endif
#ifdef NP_MSW_
		npmswSetOpenFilePath (buffer);
#endif
#ifdef NP_OSX_
		nplinuxSetOpenFilePath (buffer);
//		nposxSetOpenFilePath (buffer);
#endif
}

//-----------------------------------------------------------------------------
FILE* nposFileDialog (const char* fileName, int dialogType, void* dataRef)
{
#ifdef NP_LINUX_
 return nplinuxFileDialog (fileName, dialogType, dataRef);
#endif
#ifdef NP_MSW_
 return npmswFileDialog (fileName, dialogType, dataRef);
#endif
#ifdef NP_OSX_
 return nposxGetFileDialog (fileName, dialogType, dataRef);
#endif
}

//-----------------------------------------------------------------------------
int nposSetCursorPos (int x, int y)
{
#ifdef NP_LINUX_
 return nplinuxSetCursorPos (x,y);
#endif
#ifdef NP_MSW_
 return npmswSetCursorPos (x,y);
#endif
#ifdef NP_OSX_
 return nposxSetCursorPos (x,y);
#endif
}

//-----------------------------------------------------------------------------
int nposShowCursor (int hide)
{
#ifdef NP_LINUX_
 return nplinuxShowCursor (hide);
#endif
#ifdef NP_MSW_
 return npmswShowCursor (hide);
#endif
#ifdef NP_OSX_
 return nposxShowCursor (hide);
#endif
}

//replace this with a get nposGetSystemTime(), format CSV in npfile,		debug zz
//-----------------------------------------------------------------------------
void nposTimeStampCSV (char* fileName)
{
#ifdef NP_LINUX_
		nplinuxTimeStampCSV (fileName);
#endif
#ifdef NP_MSW_
		npmswTimeStampCSV (fileName);
#endif
#ifdef NP_OSX_
		nplinuxTimeStampCSV (fileName);
//		nposxTimeStampCSV (fileName);
#endif
}


//-----------------------------------------------------------------------------
//zz-JJ
bool nposSupportsAntzThreads()
{
	#ifdef NP_LINUX_
		return false;
	#endif
	#ifdef NP_MSW_
		return true;
	#endif
	#ifdef NP_OSX_
		return false;
	#endif
}

//zz-JJ---------------------------------------------------------------------------
void nposBeginThread(voidFnPtr vfp, void *dataRef)
{
	#ifdef NP_LINUX_
		return; // implement POSIX threads
	#endif
	#ifdef NP_MSW_
		npmswBeginThread (vfp, dataRef);
	#endif
	#ifdef NP_OSX_
		return; // implement POSIX threads
	#endif
}

//zz-JJ---------------------------------------------------------------------------
void nposEndThread()
{
	#ifdef NP_LINUX_
		return; // implement POSIX threads
	#endif
	#ifdef NP_MSW_
		npmswEndThread();
	#endif
	#ifdef NP_OSX_
		return; // implement POSIX threads
	#endif
}
//JJ-end

